@@ -74,6 +74,7 @@
 #define G1_RULE_ADVERB_ITEM_19                   "G1_rule_adverb_item_19"
 #define G1_RULE_ADVERB_ITEM_20                   "G1_rule_adverb_item_20"
 #define G1_RULE_ADVERB_ITEM_21                   "G1_rule_adverb_item_21"
+#define G1_RULE_ADVERB_ITEM_22                   "G1_rule_adverb_item_22"
 #define G1_RULE_ACTION_1                         "G1_rule_action_1"
 #define G1_RULE_ACTION_2                         "G1_rule_action_2"
 #define G1_RULE_SYMBOL_ACTION_1                  "G1_rule_symbol_action_1"
@@ -120,7 +121,6 @@
 #define G1_RULE_RHS_ALTERNATIVE_5                "G1_rule_rhs_alternative_5"
 #define G1_RULE_RHS_ALTERNATIVE_6                "G1_rule_rhs_alternative_6"
 #define G1_RULE_RHS_ALTERNATIVE_7                "G1_rule_rhs_alternative_7"
-#define G1_RULE_RHS_ALTERNATIVE_8                "G1_rule_rhs_alternative_8"
 #define G1_RULE_RHS_PRIMARY_1                    "G1_rule_rhs_primary_1"
 #define G1_RULE_RHS_PRIMARY_2                    "G1_rule_rhs_primary_2"
 #define G1_RULE_SINGLE_SYMBOL_1                  "G1_rule_single_symbol_1"
@@ -180,6 +180,9 @@
 #define G1_RULE_IF_ACTION                        "G1_rule_if_action"
 #define G1_RULE_IFACTION_NAME_1                  "G1_rule_ifaction_name_1"
 #define G1_RULE_IFACTION_NAME_2                  "G1_rule_ifaction_name_2"
+#define G1_RULE_REGEX_ACTION                     "G1_rule_regex_action"
+#define G1_RULE_REGEXACTION_NAME_1               "G1_rule_regexaction_name_1"
+#define G1_RULE_REGEXACTION_NAME_2               "G1_rule_regexaction_name_2"
 #define G1_RULE_EVENT_ACTION                     "G1_rule_event_action"
 #define G1_RULE_EVENTACTION_NAME_1               "G1_rule_eventaction_name_1"
 #define G1_RULE_EVENTACTION_NAME_2               "G1_rule_eventaction_name_2"
@@ -260,6 +263,7 @@
 #define G1_ACTION_ADVERB_ITEM_19                   "::shift" /* <adverb item> ::= <event action> */
 #define G1_ACTION_ADVERB_ITEM_20                   "::shift" /* <adverb item> ::= <default encoding> */
 #define G1_ACTION_ADVERB_ITEM_21                   "::shift" /* <adverb item> ::= <fallback encoding> */
+#define G1_ACTION_ADVERB_ITEM_22                   "::shift" /* <adverb item> ::= <regex action> */
 #define G1_ACTION_ACTION_1                         "G1_action_action_1"                         /* done */
 #define G1_ACTION_ACTION_2                         "G1_action_action_2"                         /* done */
 #define G1_ACTION_SYMBOLACTION_1                   "G1_action_symbolaction_1"                   /* done */
@@ -299,14 +303,13 @@
 #define G1_ACTION_EVENT_NAME_5                     "::ascii" /* <event name> ::= ':discard[switch]' */
 #define G1_ACTION_LHS                              "::shift" /* lhs ::= <symbol name> */
 #define G1_ACTION_RHS                              "G1_action_rhs"                              /* done */
-#define G1_ACTION_RHS_ALTERNATIVE_1                "G1_action_rhs_alternative_1"                /* done */
+#define G1_ACTION_RHS_ALTERNATIVE_1                "::shift" /* <rhs alternative> ::= <rhs primary> */
 #define G1_ACTION_RHS_ALTERNATIVE_2                "G1_action_rhs_alternative_2"                /* done */
 #define G1_ACTION_RHS_ALTERNATIVE_3                "G1_action_rhs_alternative_3"                /* done */
 #define G1_ACTION_RHS_ALTERNATIVE_4                "G1_action_rhs_alternative_4"                /* done */
 #define G1_ACTION_RHS_ALTERNATIVE_5                "G1_action_rhs_alternative_5"                /* done */
 #define G1_ACTION_RHS_ALTERNATIVE_6                "G1_action_rhs_alternative_6"                /* done */
 #define G1_ACTION_RHS_ALTERNATIVE_7                "G1_action_rhs_alternative_7"                /* done */
-#define G1_ACTION_RHS_ALTERNATIVE_8                "G1_action_rhs_alternative_8"                /* done */
 #define G1_ACTION_RHS_PRIMARY_1                    "G1_action_rhs_primary_1"                    /* done */
 #define G1_ACTION_RHS_PRIMARY_2                    "G1_action_rhs_primary_2"                    /* done */
 #define G1_ACTION_SINGLE_SYMBOL_1                  "G1_action_single_symbol_1"                  /* done */
@@ -363,6 +366,9 @@
 #define G1_ACTION_IFACTION_NAME_1                  "::ascii" /* <if action name> ::= <ascii graph name> */
 #define G1_ACTION_IFACTION_NAME_2                  "::ascii" /* <if action name> ::= <lua action name> */
 #define G1_ACTION_IFACTION                         "G1_action_ifaction"                         /* done */
+#define G1_ACTION_REGEXACTION_NAME_1               "::ascii" /* <regex action name> ::= <ascii graph name> */
+#define G1_ACTION_REGEXACTION_NAME_2               "::ascii" /* <regex action name> ::= <lua action name> */
+#define G1_ACTION_REGEXACTION                      "G1_action_regexaction"                       /* done */
 #define G1_ACTION_EVENTACTION                      "G1_action_eventaction"                   /* done */
 #define G1_ACTION_EVENTACTION_NAME_1               "::ascii" /* <event action name> ::= <ascii graph name> */
 #define G1_ACTION_EVENTACTION_NAME_2               "::ascii" /* <event action name> ::= <lua identifier> */
